searchData={"items":[{"type":"module","title":"ElixirXML","doc":"Main module for parsing, formatting, and querying XML data in Elixir.","ref":"ElixirXML.html"},{"type":"function","title":"ElixirXML.attribute/2","doc":"Retrieves the value of a specified attribute from a node.","ref":"ElixirXML.html#attribute/2"},{"type":"function","title":"ElixirXML.find/2","doc":"Finds elements by name using an XPath-like query.","ref":"ElixirXML.html#find/2"},{"type":"function","title":"ElixirXML.format/1","doc":"Formats an XML node as a string.","ref":"ElixirXML.html#format/1"},{"type":"function","title":"ElixirXML.format_document/1","doc":"Formats an XML node as a complete XML document string.","ref":"ElixirXML.html#format_document/1"},{"type":"function","title":"ElixirXML.parse/1","doc":"Parses an XML string into a structured map.","ref":"ElixirXML.html#parse/1"},{"type":"function","title":"ElixirXML.text/1","doc":"Extracts the textual content from a node.","ref":"ElixirXML.html#text/1"},{"type":"module","title":"ElixirXML.Formatter","doc":"A simple XML formatter module that converts Elixir data structures into XML strings.\n\nThis module supports formatting:\n- Plain text (binary strings)\n- Lists of elements\n- Maps representing XML nodes with attributes and children","ref":"ElixirXML.Formatter.html"},{"type":"function","title":"ElixirXML.Formatter.format/1","doc":"Formats different types of input into XML-compliant strings.","ref":"ElixirXML.Formatter.html#format/1"},{"type":"function","title":"Supported Inputs: - ElixirXML.Formatter.format/1","doc":"- `binary`: Returns the text as-is.\n- `list`: Recursively formats each element and concatenates them.\n- `map`: Converts a structured map into an XML tag.","ref":"ElixirXML.Formatter.html#format/1-supported-inputs"},{"type":"function","title":"Examples - ElixirXML.Formatter.format/1","doc":"iex> ElixirXML.Formatter.format(\"Hello\")\n    \"Hello\"\n\n    iex> ElixirXML.Formatter.format([\"Hello\", \" World\"])\n    \"Hello World\"\n\n    iex> ElixirXML.Formatter.format(%{name: \"br\", attributes: [], children: []})\n    \" \"\n\n    iex> ElixirXML.Formatter.format(%{name: \"p\", attributes: [], children: [\"Hello\"]})\n    \" Hello \"","ref":"ElixirXML.Formatter.html#format/1-examples"},{"type":"function","title":"ElixirXML.Formatter.format_document/1","doc":"","ref":"ElixirXML.Formatter.html#format_document/1"},{"type":"module","title":"ElixirXML.Namespace","doc":"A module for handling XML namespaces, including extracting and reversing XML namespace mappings.\n\nThis module provides:\n- `extract/2`: Parses XML elements and separates namespaces.\n- `reverse/2`: Reconstructs prefixed XML names from namespace mappings.","ref":"ElixirXML.Namespace.html"},{"type":"function","title":"ElixirXML.Namespace.extract/2","doc":"Extracts namespaces from XML elements and normalizes them.","ref":"ElixirXML.Namespace.html#extract/2"},{"type":"function","title":"Examples - ElixirXML.Namespace.extract/2","doc":"iex> ElixirXML.Namespace.extract(%{name: \"ns:tag\", attributes: [{\"xmlns:ns\", \"http://example.com\"}], children: []})\n    %{name: \"tag\", ns: \"http://example.com\", attributes: [], children: []}","ref":"ElixirXML.Namespace.html#extract/2-examples"},{"type":"function","title":"ElixirXML.Namespace.reverse/2","doc":"Reverses namespace extraction, restoring prefixed XML names.","ref":"ElixirXML.Namespace.html#reverse/2"},{"type":"function","title":"Examples - ElixirXML.Namespace.reverse/2","doc":"iex> ElixirXML.Namespace.reverse(%{name: \"tag\", ns: \"http://example.com\", attributes: [], children: []})\n    %{name: \"ns:tag\", attributes: [{\"xmlns:ns\", \"http://example.com\"}], children: []}","ref":"ElixirXML.Namespace.html#reverse/2-examples"},{"type":"module","title":"ElixirXML.Parser","doc":"XML Parser for converting raw XML text into structured Elixir maps.","ref":"ElixirXML.Parser.html"},{"type":"function","title":"ElixirXML.Parser.parse/1","doc":"Parses an XML string and returns a structured representation.","ref":"ElixirXML.Parser.html#parse/1"},{"type":"function","title":"Examples - ElixirXML.Parser.parse/1","doc":"iex> ElixirXML.Parser.parse(\"  Content  \")\n    %{name: \"root\", attributes: %{}, children: [%{name: \"child\", attributes: %{}, children: [\"Content\"]}]}","ref":"ElixirXML.Parser.html#parse/1-examples"},{"type":"module","title":"ElixirXML.Query","doc":"A module for querying XML-like structures in Elixir.\nProvides functions to find nodes using XPath-like syntax, extract text content,\nand retrieve attributes.","ref":"ElixirXML.Query.html"},{"type":"function","title":"ElixirXML.Query.attribute/2","doc":"Retrieves an attribute from an XML node.","ref":"ElixirXML.Query.html#attribute/2"},{"type":"function","title":"Examples - ElixirXML.Query.attribute/2","doc":"iex> ElixirXML.Query.attribute(%{attributes: %{class: \"header\"}}, \"class\")\n    \"header\"","ref":"ElixirXML.Query.html#attribute/2-examples"},{"type":"function","title":"ElixirXML.Query.find/2","doc":"Finds nodes matching the given XPath-like expression.","ref":"ElixirXML.Query.html#find/2"},{"type":"function","title":"Examples - ElixirXML.Query.find/2","doc":"iex> ElixirXML.Query.find(xml_data, \"//book/title\")\n    [\"Elixir in Action\"]","ref":"ElixirXML.Query.html#find/2-examples"},{"type":"function","title":"ElixirXML.Query.text/1","doc":"Extracts all text content from an element and its children.","ref":"ElixirXML.Query.html#text/1"},{"type":"function","title":"Examples - ElixirXML.Query.text/1","doc":"iex> ElixirXML.Query.text(%{children: [\"Hello\", %{children: [\" World\"]}]})\n    \"Hello World\"","ref":"ElixirXML.Query.html#text/1-examples"},{"type":"module","title":"ElixirXML.Scanner","doc":"A simple XML scanner that tokenizes an XML buffer into structured elements.\n\nThis module processes XML content and extracts meaningful components such as:\n- XML headers\n- Opening and closing tags\n- Attributes\n- Text content\n\nIt provides a `scan/1` function that processes an input buffer and returns structured tuples.","ref":"ElixirXML.Scanner.html"},{"type":"function","title":"ElixirXML.Scanner.scan/1","doc":"Scans an XML buffer and returns a tuple representing the next XML element.","ref":"ElixirXML.Scanner.html#scan/1"},{"type":"function","title":"Examples - ElixirXML.Scanner.scan/1","doc":"iex> ElixirXML.Scanner.scan(\" \")\n    {{:element_open, \"tag\", []}, \"\"}","ref":"ElixirXML.Scanner.html#scan/1-examples"},{"type":"extras","title":"ElixirXML","doc":"# ElixirXML\n\nElixirXML (based in [Elixml](https://github.com/mlankenau/elixml)) is an improved and optimized XML library for Elixir that makes it easy to:\n\n- Parse XML files (with improved performance)\n- Query XML\n  - Optimized searching mechanism\n  - XPath (in progress)\n- Namespace support (implemented)\n- Export to file/text (enhanced implementation)\n- Compose documents\n  - Simple to use with maps\n  - DSL support (under development)","ref":"readme.html"},{"type":"extras","title":"Installation - ElixirXML","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed by adding `elixir_xml` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:elixir_xml, github: \"https://github.com/OscarTinajero117/elixir_xml\"}\n  ]\nend\n\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ElixirXML","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Parse an XML file - ElixirXML","doc":"Consider the following example XML file my_file.xml:\n\n```xml\n \n   \n     a_1 \n     a_2 \n   \n   \n     b_1 \n     b_2 \n   \n   \n     \n       foo \n     \n   \n \n```\n\nYou can load it with:\n\n```elixir\nmydoc =\n  File.read!(\"my_file.xml\")\n  |> ElixirXML.parse\n\n# returns the root element like\n# %{name: \"root\", children: [...], attributes: [...]}\n```","ref":"readme.html#parse-an-xml-file"},{"type":"extras","title":"Find elements - ElixirXML","doc":"```sh\nElixirXML.find(mydoc, \"//group_a\")\n# returns the list of elements found (only one)\n```","ref":"readme.html#find-elements"},{"type":"extras","title":"Access text - ElixirXML","doc":"```sh\nElixirXML.find(mydoc, \"//subchild\") |> hd |> ElixirXML.text()\n# returns \"foo\"\n```","ref":"readme.html#access-text"},{"type":"extras","title":"Access attributes - ElixirXML","doc":"```sh\nElixirXML.find(mydoc, \"//group_a\") |> hd |> ElixirXML.attribute(\"id\")\n# returns \"1\"\n```","ref":"readme.html#access-attributes"},{"type":"extras","title":"Reconstruct XML Document - ElixirXML","doc":"```elixir\nchild1 = ElixirXML.find(mydoc, \"//child1\") |> hd\nElixirXML.format_document(child1)\n# returns\n# \"\"\"\n#  <?xml version=\"1.0\" encoding=\"UTF-8\"?>\n#   \n#     foo \n#   \n# \"\"\"\n```","ref":"readme.html#reconstruct-xml-document"},{"type":"extras","title":"Features - ElixirXML","doc":"- Improved parsing speed: Optimized to handle large XML files efficiently.\n- Namespace support: Now fully supports XML namespaces.\n- XPath support: The XPath querying is under development but planned to be released soon.\n- Document composition: Easy to build new XML documents with maps, with plans for a flexible DSL for advanced use cases.","ref":"readme.html#features"},{"type":"extras","title":"Documentation - ElixirXML","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc) and published on [HexDocs](https://hexdocs.pm). Once published, the docs can be found at [https://hexdocs.pm/ElixirXML](https://hexdocs.pm/ElixirXML).","ref":"readme.html#documentation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}